:orphan:

.. include:: _contributors.rst
.. currentmodule:: treeple

.. _current:

Version 0.10
============

** In Development **

Changelog
---------

- |Feature| Calculations involving nans in ``treeple.stats.utils`` now use the
    ``bottleneck`` library for faster computation. By `Ryan Hausen`_ (:pr:`#306`)
- |Feature| Added a sparse implementation of `treeple.stats.forest.build_colemen_forest`
    that uses the `scipy.sparse` module. By `Ryan Hausen`_ (:pr:`#317`)
- |Feature| :class:`treeple.tree.HonestTreeClassifier` now has a ``honest_method`` parameter
    that enables the user to turn on pruning of the tree, such that there are no
    empty leaf predictions. This brings the model closer to the implementation in GRF in R.
    By `Adam Li`_ (:pr:`#286`)


Code and Documentation Contributors
-----------------------------------

Thanks to everyone who has contributed to the maintenance and improvement of
the project since version inception, including:

* `Adam Li`_
* `Ryan Hausen`_
